.. _How Do I:

How do I?
##########

Looking to do something specific with glue genes? You've come to the right place.

==================================      ==============================================================
How do I...                             Guide
==================================      ==============================================================
install glue genes?                     :ref:`Installing glue genes<Installation>`
start glue genes?                       :ref:`Stating glue genes<Starting>`
get my data into glue genes?            :ref:`Loading data<Get Data In>`
link my datasets?                       :ref:`Linking data<Link Data>`
visualize my data?                      :ref:`Visualize data<Visualize Data>`
visualize an expression matrix?         :ref:`Visualize expression matrix<Visualize Expression Matrix>`
connect cell and expression data?       :ref:`Cells to Genes<Cells to Genes>`
link observations and images?           :ref:`Linking observations and images<Linking Observations and Images>`
==================================      ==============================================================


.. toctree::
   :maxdepth: 2
   :hidden:

   installation
   starting
   data-in
   linking-data
   visualize-data
   cells-to-genes
   visualize-expression-matrix
   linking-observations-and-images
